"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Cache = /** @class */ (function () {
    function Cache() {
        this.enabled = true;
        this.values = {};
        this.changeListeners = [];
        this.destroyListeners = [];
    }
    Cache.prototype.get = function (key) {
        return this.values[key];
    };
    Cache.prototype.set = function (key, value) {
        if (this.enabled) {
            this.values[key] = value;
            this.emitChange(key, value);
        }
        return value;
    };
    Cache.prototype.destroy = function (key) {
        if (this.enabled && typeof this.values[key] !== "undefined") {
            delete this.values[key];
            this.emitDestroy(key);
        }
    };
    Cache.prototype.clear = function () {
        this.values = {};
    };
    Cache.prototype.onChange = function (callback) {
        this.changeListeners.push(callback);
    };
    Cache.prototype.emitChange = function (key, value) {
        this.changeListeners.forEach(function (callback) { return callback(key, value); });
    };
    Cache.prototype.onDestroy = function (callback) {
        this.destroyListeners.push(callback);
    };
    Cache.prototype.emitDestroy = function (key) {
        this.destroyListeners.forEach(function (callback) { return callback(key); });
    };
    return Cache;
}());
exports.default = Cache;
//# sourceMappingURL=Cache.js.map